@@ -30,7 +30,14 @@ void KasumiDic::load() throw(KasumiDicExaminationException){
   ifstream DicFile(DicFileName.c_str());
 
   if(!DicFile.is_open()){
-          throw KasumiDicExaminationException("Cannot open Anthy dicitionary file.", 0);
+    DicFile.close();    
+    ofstream NewDicFile(DicFileName.c_str());
+    NewDicFile.close();
+    DicFile.open(DicFileName.c_str());
+  }
+  
+  if(!DicFile.is_open()){
+    throw KasumiDicExaminationException("Cannot open Anthy dicitionary file.", 0);
   }
 
   // analyze Anthy Dictionary reading each line
@@ -113,6 +120,11 @@ void KasumiDic::removeWord(int id) throw(KasumiOutOfBoundException){
 
 void KasumiDic::store() throw(KasumiDicStoreException){
   int i;
+  ofstream DicFile(DicFileName.c_str());
+  if(!DicFile.is_open()){
+    cout << "Cannot overwrite data to" << DicFileName << "." << endl;
+    return;
+  }
   string ret = string();
   
   for(i=0; i<WordList.size(); i++){
@@ -149,7 +161,16 @@ void KasumiDic::store() throw(KasumiDicStoreException){
     ret += "\n";
   }
 
-  cout << ret;
+  DicFile << ret;
+  DicFile.close();
+
+  string command = "cat " + DicFileName + "|anthy-dic-tool --load";
+  if(system(command.c_str()) == 0){
+    cout << "correctly registered dictionary" << endl;
+  }else{
+    cout << "cannot register dicitionary for some reason" << endl;
+    exit(1);
+  }
 }
 
 void KasumiDic::registerEventListener(KasumiDicEventListener *listener){
